package uk.co.martinpearman.b4a.mylistview.arrayadapter;

import java.util.List;

import android.content.Context;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.TextView;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Hide;

@Hide
public class MyListViewAdapter extends ArrayAdapter<MyDataClass> {
	
	/*
	 * This is the custom ArrayAdapter class.
	 * 
	 * http://developer.android.com/reference/android/widget/ArrayAdapter.html
	 * 
	 */
	
	private int mItemLayoutResourceId;
	private LayoutInflater mLayoutInflater;
	private List<MyDataClass> mMyDataClassList;
	private String[] mTextViewIds;
	
	public MyListViewAdapter(Context pContext, int pItemLayoutResourceId, int pTextViewResourceId, List<MyDataClass> pMyDataClassList) {
		super(pContext, pItemLayoutResourceId, pTextViewResourceId, pMyDataClassList);
		
		mItemLayoutResourceId=pItemLayoutResourceId;
		
		/*
		 * A reference to the LayoutInflater is kept to avoid calling it each time a new ListItem is required.
		 * 
		 * But look at the Log output - when the ListView is created the LayoutInflater is used, after that it is seldom used as ListItems are recycled.
		 * If your ListItems vary in height then there is a chance the LayoutInflater will again be re-used.
		 * 
		 * You choose whether keeping a reference to it is a resource waste or not!
		 * 
		 */
		mLayoutInflater=LayoutInflater.from(pContext);
		
		mMyDataClassList=pMyDataClassList;
		
		/*
		 * These are the ids of the textViews in my ListItem layout.
		 * 
		 * MyListViewWrapper uses the same ids to add values to a MyDataClass instance.
		 * You'll probably want to use your own technique instead of my technique track TextView ids and Array values.
		 * 
		 */
		mTextViewIds=new String[]{"item_title", "item_description"};
	}
	
	/*
	 * A helper method to find a View in the ListItem.
	 */
	private static View findViewById(View pView, String pId) {
		return pView.findViewById(BA.applicationContext.getResources().getIdentifier(pId, "id", BA.packageName));
	}
	
	@Override
	public View getView(int pPosition, View pConvertView, ViewGroup pParent) {
		/*
		 * getView() is called when the ListView needs to make a ListItem visible.
		 * 
		 * A previously visible but no longer visible ListItem may be recycled otherwise a new ListItem is created.
		 * 
		 */
		if (pConvertView == null) {
			Log.i("B4A", "New ListItem created");
			pConvertView = mLayoutInflater.inflate(mItemLayoutResourceId, null);
		} else {
			Log.i("B4A", "Existing ListItem recycled");
		}
		MyDataClass dataItem = mMyDataClassList.get(pPosition);
		if (dataItem != null) {
			TextView textView;
			for(int i=0, j=mTextViewIds.length; i<j; i++){
				textView=(TextView)findViewById(pConvertView, mTextViewIds[i]);
				textView.setText((String) dataItem.get(mTextViewIds[i]));
			}
		}
		/*
		 * If dataItem is null and this is a recycled View then the recycled View will retain it's old values..
		 * 
		 * It's probably not possible/likely that dataItem will be null?
		 * 
		 */
		return pConvertView;
	}
}
